==========
python-lz4
==========

Status
======

.. image:: https://travis-ci.org/python-lz4/python-lz4.svg?branch=master
   :target: https://travis-ci.org/python-lz4/python-lz4
   :alt: Build Status

.. image:: https://ci.appveyor.com/api/projects/status/github/python-lz4/python-lz4?branch=master
   :target: https://ci.appveyor.com/project/jonathanunderwood/python-lz4
   :alt: Build Status Windows

.. image:: https://readthedocs.org/projects/python-lz4/badge/?version=latest
   :target: https://readthedocs.org/projects/python-lz4/
   :alt: Documentation

Introduction
============
This package provides python bindings for the `lz4 compression library
<https://cyan4973.github.io/lz4//>`_ by Yann Collet.

At this time the project contains bindings for the LZ4 block format, which are
considered stable.

Support for the LZ4 frame format is a work-in-progress and is considered beta
quality. It should work fine, but changes to the API may happen prior to the 1.0
release.

A future relase will implement support for the LZ4 stream format.

Documenation
============

.. image:: https://readthedocs.org/projects/python-lz4/badge/?version=latest
   :target: https://readthedocs.org/projects/python-lz4/
   :alt: Documentation

Full documentation is included with the project. The documentation is
generated using Sphinx. Documentation is also hosted on readthedocs.

:master: http://python-lz4.readthedocs.io/en/latest/

Licensing
=========
Code specific to this project is covered by the `BSD 3-Clause License
<http://opensource.org/licenses/BSD-3-Clause>`_

